#[non_exhaustive]pub struct RoomCreateEventContent {
pub creator: Option<OwnedUserId>,
pub federate: bool,
pub room_version: RoomVersionId,
pub predecessor: Option<PreviousRoom>,
pub room_type: Option<RoomType>,
pub additional_creators: Vec<OwnedUserId>,
}Expand description
The content of an m.room.create event.
This is the first event in a room and cannot be changed.
It acts as the root of all other events.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.creator: Option<OwnedUserId>The user_id of the room creator.
This is set by the homeserver.
This is required in room versions 1 trough 10, but is removed starting from room version 11.
federate: boolWhether or not this room’s data should be transferred to other homeservers.
room_version: RoomVersionIdThe version of the room.
Defaults to RoomVersionId::V1.
predecessor: Option<PreviousRoom>A reference to the room this room replaces, if the previous room was upgraded.
With the compat-lax-room-create-deser cargo feature, this field is ignored if its
deserialization fails.
room_type: Option<RoomType>The room type.
This is currently only used for spaces.
additional_creators: Vec<OwnedUserId>Additional room creators, considered to have “infinite” power level, in room version 12 onwards.
Implementations
Sourceimpl RoomCreateEventContent
impl RoomCreateEventContent
Sourcepub fn new_v1(creator: OwnedUserId) -> Self
pub fn new_v1(creator: OwnedUserId) -> Self
Creates a new RoomCreateEventContent with the given creator, as required for room versions
1 through 10.
Sourcepub fn new_v11() -> Self
pub fn new_v11() -> Self
Creates a new RoomCreateEventContent with the default values and no creator, as introduced
in room version 11.
The room version is set to RoomVersionId::V11.